/// <reference types="node" />
/// <reference types="@solana/web3.js" />
import * as _solana from "@wormhole-foundation/sdk-solana";
/** Platform and protocol definitons for Solana */
export declare const solana: {
    protocols: {
        core: Promise<{
            default: typeof import("@wormhole-foundation/sdk-solana-core");
            utils: typeof import("@wormhole-foundation/sdk-solana-core/dist/cjs/utils");
            SolanaWormholeCore: typeof import("@wormhole-foundation/sdk-solana-core").SolanaWormholeCore;
        }>;
        tokenbridge: Promise<{
            default: typeof import("@wormhole-foundation/sdk-solana-tokenbridge");
            IDL: import("@wormhole-foundation/sdk-solana-tokenbridge").TokenBridgeRelayer;
            deriveForeignContractAddress(programId: import("@solana/web3.js").PublicKeyInitData, chainId: "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Dymension" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky"): import("@solana/web3.js").PublicKey;
            deriveRedeemerConfigAddress(programId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveRegisteredTokenAddress(programId: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveSenderConfigAddress(programId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveTmpTokenAccountAddress(programId: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveTokenTransferMessageAddress(programId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, sequence: import("bn.js")): import("@solana/web3.js").PublicKey;
            createTransferNativeTokensWithRelayInstruction(connection: import("@solana/web3.js").Connection, programId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData, amount: bigint, toNativeTokenAmount: bigint, recipientAddress: Uint8Array, recipientChain: "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Dymension" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky", batchId: number, wrapNative: boolean): Promise<import("@solana/web3.js").TransactionInstruction>;
            createTransferWrappedTokensWithRelayInstruction(connection: import("@solana/web3.js").Connection, programId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData, amount: bigint, toNativeTokenAmount: bigint, recipientAddress: Uint8Array, recipientChain: "Solana" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Base" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Neutron" | "Celestia" | "Stargaze" | "Dymension" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky", batchId: number): Promise<import("@solana/web3.js").TransactionInstruction>;
            createTokenBridgeRelayerProgramInterface(programId: import("@solana/web3.js").PublicKeyInitData, connection: import("@solana/web3.js").Connection): import("@project-serum/anchor").Program<import("@wormhole-foundation/sdk-solana-tokenbridge").TokenBridgeRelayer>;
            deriveTokenBridgeConfigKey(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            getTokenBridgeConfig(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, commitment?: import("@solana/web3.js").Commitment | undefined): Promise<import("@wormhole-foundation/sdk-solana-tokenbridge").TokenBridgeConfig>;
            TokenBridgeConfig: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").TokenBridgeConfig;
            deriveCustodyKey(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveEndpointKey(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, emitterChain: number, emitterAddress: string | Uint8Array | Buffer): import("@solana/web3.js").PublicKey;
            getEndpointRegistration(connection: import("@solana/web3.js").Connection, endpointKey: import("@solana/web3.js").PublicKeyInitData, commitment?: import("@solana/web3.js").Commitment | undefined): Promise<import("@wormhole-foundation/sdk-solana-tokenbridge").EndpointRegistration>;
            EndpointRegistration: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").EndpointRegistration;
            deriveSenderAccountKey(cpiProgramId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveRedeemerAccountKey(cpiProgramId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveAuthoritySignerKey(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveCustodySignerKey(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveMintAuthorityKey(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            deriveWrappedMintKey(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, tokenChain: number, tokenAddress: Uint8Array | Buffer): import("@solana/web3.js").PublicKey;
            deriveWrappedMetaKey(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            getWrappedMeta(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData, commitment?: import("@solana/web3.js").Commitment | undefined): Promise<import("@wormhole-foundation/sdk-solana-tokenbridge").WrappedMeta>;
            WrappedMeta: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").WrappedMeta;
            getTokenBridgeDerivedAccounts(cpiProgramId: import("@solana/web3.js").PublicKeyInitData, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData): import("@wormhole-foundation/sdk-solana-tokenbridge").TokenBridgeDerivedAccounts;
            getTransferNativeWithPayloadCpiAccounts(cpiProgramId: import("@solana/web3.js").PublicKeyInitData, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, fromTokenAccount: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData): import("@wormhole-foundation/sdk-solana-tokenbridge").TransferNativeWithPayloadCpiAccounts;
            getTransferWrappedWithPayloadCpiAccounts(cpiProgramId: import("@solana/web3.js").PublicKeyInitData, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, fromTokenAccount: import("@solana/web3.js").PublicKeyInitData, tokenChain: number, tokenAddress: Uint8Array | Buffer, fromTokenAccountOwner?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@wormhole-foundation/sdk-solana-tokenbridge").TransferWrappedWithPayloadCpiAccounts;
            getCompleteTransferNativeWithPayloadCpiAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:Transfer"> | import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:TransferWithPayload">, toTokenAccount: import("@solana/web3.js").PublicKeyInitData): import("@wormhole-foundation/sdk-solana-tokenbridge").CompleteTransferNativeWithPayloadCpiAccounts;
            getCompleteTransferWrappedWithPayloadCpiAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:Transfer"> | import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:TransferWithPayload">, toTokenAccount: import("@solana/web3.js").PublicKeyInitData): import("@wormhole-foundation/sdk-solana-tokenbridge").CompleteTransferWrappedWithPayloadCpiAccounts;
            createApproveAuthoritySignerInstruction(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, tokenAccount: import("@solana/web3.js").PublicKeyInitData, owner: import("@solana/web3.js").PublicKeyInitData, amount: number | bigint): import("@solana/web3.js").TransactionInstruction;
            createAttestTokenInstruction(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, nonce: number): import("@solana/web3.js").TransactionInstruction;
            getAttestTokenAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData): import("@wormhole-foundation/sdk-solana-tokenbridge").AttestTokenAccounts;
            createCompleteTransferNativeInstruction(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:Transfer"> | import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:TransferWithPayload">, feeRecipient?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@solana/web3.js").TransactionInstruction;
            getCompleteTransferNativeAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:Transfer"> | import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:TransferWithPayload">, feeRecipient?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@wormhole-foundation/sdk-solana-tokenbridge").CompleteTransferNativeAccounts;
            createCompleteTransferWrappedInstruction(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:Transfer"> | import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:TransferWithPayload">, feeRecipient?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@solana/web3.js").TransactionInstruction;
            getCompleteTransferWrappedAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:Transfer"> | import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:TransferWithPayload">, feeRecipient?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@wormhole-foundation/sdk-solana-tokenbridge").CompleteTransferWrappedAccounts;
            createCreateWrappedInstruction(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:AttestMeta">): import("@solana/web3.js").TransactionInstruction;
            getCreateWrappedAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:Transfer"> | import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:TransferWithPayload"> | import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:AttestMeta">): import("@wormhole-foundation/sdk-solana-tokenbridge").CreateWrappedAccounts;
            createInitializeInstruction(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").TransactionInstruction;
            getInitializeAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData): import("@wormhole-foundation/sdk-solana-tokenbridge").InitializeAccounts;
            createRegisterChainInstruction(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:RegisterChain">): import("@solana/web3.js").TransactionInstruction;
            getRegisterChainAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:RegisterChain">): import("@wormhole-foundation/sdk-solana-tokenbridge").RegisterChainAccounts;
            createUpgradeContractInstruction(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:UpgradeContract">, spill?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@solana/web3.js").TransactionInstruction;
            getUpgradeContractAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, vaa: import("@wormhole-foundation/sdk-definitions").VAA<"TokenBridge:UpgradeContract">, spill?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@wormhole-foundation/sdk-solana-tokenbridge").UpgradeContractAccounts;
            createTransferNativeInstruction(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, from: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData, nonce: number, amount: bigint, fee: bigint, targetAddress: Uint8Array | Buffer, targetChain: number): import("@solana/web3.js").TransactionInstruction;
            getTransferNativeAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, from: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData): import("@wormhole-foundation/sdk-solana-tokenbridge").TransferNativeAccounts;
            createTransferNativeWithPayloadInstruction(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, from: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData, nonce: number, amount: bigint, targetAddress: Uint8Array | Buffer, targetChain: number, payload: Uint8Array | Buffer): import("@solana/web3.js").TransactionInstruction;
            getTransferNativeWithPayloadAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, from: import("@solana/web3.js").PublicKeyInitData, mint: import("@solana/web3.js").PublicKeyInitData, cpiProgramId?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@wormhole-foundation/sdk-solana-tokenbridge").TransferNativeWithPayloadAccounts;
            createTransferWrappedInstruction(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, from: import("@solana/web3.js").PublicKeyInitData, fromOwner: import("@solana/web3.js").PublicKeyInitData, tokenChain: number, tokenAddress: Uint8Array | Buffer, nonce: number, amount: bigint, fee: bigint, targetAddress: Uint8Array | Buffer, targetChain: number): import("@solana/web3.js").TransactionInstruction;
            getTransferWrappedAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, from: import("@solana/web3.js").PublicKeyInitData, fromOwner: import("@solana/web3.js").PublicKeyInitData, tokenChain: number, tokenAddress: Uint8Array | Buffer): import("@wormhole-foundation/sdk-solana-tokenbridge").TransferWrappedAccounts;
            createTransferWrappedWithPayloadInstruction(connection: import("@solana/web3.js").Connection, tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, from: import("@solana/web3.js").PublicKeyInitData, fromOwner: import("@solana/web3.js").PublicKeyInitData, tokenChain: number, tokenAddress: Uint8Array | Buffer, nonce: number, amount: bigint, targetAddress: Uint8Array | Buffer, targetChain: number, payload: Uint8Array | Buffer): import("@solana/web3.js").TransactionInstruction;
            getTransferWrappedWithPayloadAccounts(tokenBridgeProgramId: import("@solana/web3.js").PublicKeyInitData, wormholeProgramId: import("@solana/web3.js").PublicKeyInitData, payer: import("@solana/web3.js").PublicKeyInitData, message: import("@solana/web3.js").PublicKeyInitData, from: import("@solana/web3.js").PublicKeyInitData, fromOwner: import("@solana/web3.js").PublicKeyInitData, tokenChain: number, tokenAddress: Uint8Array | Buffer, cpiProgramId?: import("@solana/web3.js").PublicKeyInitData | undefined): import("@wormhole-foundation/sdk-solana-tokenbridge").TransferWrappedWithPayloadAccounts;
            createTokenBridgeProgramInterface(programId: import("@solana/web3.js").PublicKeyInitData, provider?: import("@project-serum/anchor").Provider | undefined): import("@project-serum/anchor").Program<import("@wormhole-foundation/sdk-solana-tokenbridge").TokenBridge>;
            createReadOnlyTokenBridgeProgramInterface(programId: import("@solana/web3.js").PublicKeyInitData, connection?: import("@solana/web3.js").Connection | undefined): import("@project-serum/anchor").Program<import("@wormhole-foundation/sdk-solana-tokenbridge").TokenBridge>;
            coder(): import("@wormhole-foundation/sdk-solana-tokenbridge/dist/cjs/utils/tokenBridge/coder").TokenBridgeCoder;
            deriveSplTokenMetadataKey(mint: import("@solana/web3.js").PublicKeyInitData): import("@solana/web3.js").PublicKey;
            getMetadata(connection: import("@solana/web3.js").Connection, mint: import("@solana/web3.js").PublicKeyInitData, commitment?: import("@solana/web3.js").Commitment | undefined): Promise<import("@wormhole-foundation/sdk-solana-tokenbridge").Metadata>;
            Creator: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").Creator;
            Data: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").Data;
            CreateMetadataAccountArgs: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").CreateMetadataAccountArgs;
            SplTokenMetadataProgram: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").SplTokenMetadataProgram;
            Key: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").Key;
            Metadata: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").Metadata;
            SolanaTokenBridge: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").SolanaTokenBridge;
            SolanaAutomaticTokenBridge: typeof import("@wormhole-foundation/sdk-solana-tokenbridge").SolanaAutomaticTokenBridge;
        }>;
        cctp: Promise<{
            default: typeof import("@wormhole-foundation/sdk-solana-cctp");
            idl: {
                TokenMessengerIdl: import("@wormhole-foundation/sdk-solana-cctp").TokenMessenger;
                MessageTransmitterIdl: import("@wormhole-foundation/sdk-solana-cctp").MessageTransmitter;
            };
            SolanaCircleBridge: typeof import("@wormhole-foundation/sdk-solana-cctp").SolanaCircleBridge;
        }>;
    };
    Address: typeof _solana.SolanaAddress;
    ChainContext: typeof _solana.SolanaChain;
    Platform: typeof _solana.SolanaPlatform;
    Signer: typeof _solana.SolanaSigner;
    getSigner: typeof _solana.getSolanaSignAndSendSigner;
};
//# sourceMappingURL=solana.d.ts.map